@@ -109,6 +109,8 @@ setGeneric("instrumentModel", function(object) standardGeneric("instrumentModel"
 
 setGeneric("smooth", function(x, ...) standardGeneric("smooth")) ## stats::smooth already exists
 setGeneric("combineFeatures", function(object, ...) standardGeneric("combineFeatures"))
+setGeneric("aggregateFeatures", function(object, ...) standardGeneric("aggregateFeatures"))
+setGeneric("impute", function(object, ...) standardGeneric("impute"))
 
 ## -------------------------------------------------------------
 ## IO
@@ -132,3 +134,4 @@ setGeneric("filterProductMz", function(object, ...) standardGeneric("filterProdu
 setGeneric("filterPrecursorScan", function(object, ...) standardGeneric("filterPrecursorScan"))
 setGeneric("filterRt", function(object, ...) standardGeneric("filterRt"))
 setGeneric("filterMz", function(object, ...) standardGeneric("filterMz"))
+setGeneric("filterNA", function(object, ...) standardGeneric("filterNA"))
